==> webcamoid_8.0.0+dfsg.orig.tar.gz: webcamoid-8.0.0/libAvKys/Plugins/Swirl/src/swirlelement.h <==
/* Webcamoid, webcam capture application.
 * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#ifndef SWIRLELEMENT_H
#define SWIRLELEMENT_H

#include <QQmlComponent>
#include <QQmlContext>
#include <ak.h>
#include <akutils.h>

class SwirlElement: public AkElement
{
    Q_OBJECT
    Q_PROPERTY(qreal degrees
               READ degrees
               WRITE setDegrees
               RESET resetDegrees
               NOTIFY degreesChanged)

    public:
        explicit SwirlElement();

        Q_INVOKABLE QObject *controlInterface(QQmlEngine *engine,
                                              const QString &controlId) const;

        Q_INVOKABLE qreal degrees() const;

    private:
        qreal m_degrees;

    signals:
        void degreesChanged(qreal degrees);

    public slots:
        void setDegrees(qreal degrees);
        void resetDegrees();
        AkPacket iStream(const AkPacket &packet);
};

#endif // SWIRLELEMENT_H

==> webcamoid_8.1.0+dfsg.orig.tar.gz: webcamoid-8.1.0+dfsg/libAvKys/Plugins/Swirl/src/swirlelement.h <==
/* Webcamoid, webcam capture application.
 * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#ifndef SWIRLELEMENT_H
#define SWIRLELEMENT_H

#include <ak.h>
#include <akutils.h>

class SwirlElement: public AkElement
{
    Q_OBJECT
    Q_PROPERTY(qreal degrees
               READ degrees
               WRITE setDegrees
               RESET resetDegrees
               NOTIFY degreesChanged)

    public:
        explicit SwirlElement();

        Q_INVOKABLE qreal degrees() const;

    private:
        qreal m_degrees;

    protected:
        QString controlInterfaceProvide(const QString &controlId) const;
        void controlInterfaceConfigure(QQmlContext *context,
                                       const QString &controlId) const;

    signals:
        void degreesChanged(qreal degrees);

    public slots:
        void setDegrees(qreal degrees);
        void resetDegrees();
        AkPacket iStream(const AkPacket &packet);
};

#endif // SWIRLELEMENT_H
